@@ -6,6 +6,7 @@ const { sync } = require("find-up");
 
 process.argv.splice(0, 2);
 const isSynth = process.argv.filter(p => !p.startsWith("--")).length === 0;
+const isInstall = process.argv[0] === "install";
 
 if (process.argv[0] == "new") {
   execa.commandSync(`npx --yes projen@latest new --from @aws/pdk ${process.argv.slice(1).join(" ")}`, { stdio: "inherit" });
@@ -27,8 +28,14 @@ const engines = JSON.parse(
 ).engines;
 
 if (engines) {
-  const pkgMgr = engines.pnpm ? "pnpm" : engines.yarn ? "yarn" : "npm";
-  execa.commandSync(`${pkgMgr}${isSynth ? " projen" : ""} ${process.argv.join(" ")}`, { stdio: "inherit" });
+  let pkgMgrCmd = engines.pnpm ? "pnpm" : engines.yarn ? "yarn" : engines.bun ? `bun${isInstall ? '' : ' run'}` : "npm run";
+
+  // deploy and upgrade are pnpm commands, but it's more likely users want to run the projen tasks
+  // upgrade is also a yarn command, and there's no difference between running yarn deploy vs yarn run deploy
+  if ((engines.pnpm || engines.yarn) && ["deploy", "upgrade"].includes(process.argv[0])) {
+    pkgMgrCmd += " run";
+  }
+  execa.commandSync(`${pkgMgrCmd}${isSynth ? " default" : ""} ${process.argv.join(" ")}`, { stdio: "inherit" });
 } else {
   execa.commandSync(`npx projen ${process.argv.join(" ")}`, { stdio: "inherit"});
 }
