@@ -66,6 +66,169 @@ class AwsPrototypingChecks(
         return typing.cast(None, jsii.invoke(self, "visit", [node]))
 
 
+@jsii.data_type(
+    jsii_type="@aws/pdk.pdk_nag.ExtendedNagResult",
+    jsii_struct_bases=[],
+    name_mapping={
+        "compliance": "compliance",
+        "nag_pack_name": "nagPackName",
+        "resource": "resource",
+        "rule_explanation": "ruleExplanation",
+        "rule_id": "ruleId",
+        "rule_info": "ruleInfo",
+        "rule_level": "ruleLevel",
+        "rule_original_name": "ruleOriginalName",
+        "error_message": "errorMessage",
+        "finding_id": "findingId",
+        "suppression_reason": "suppressionReason",
+    },
+)
+class ExtendedNagResult:
+    def __init__(
+        self,
+        *,
+        compliance: "NagResultCompliance",
+        nag_pack_name: builtins.str,
+        resource: _aws_cdk_ceddda9d.CfnResource,
+        rule_explanation: builtins.str,
+        rule_id: builtins.str,
+        rule_info: builtins.str,
+        rule_level: _cdk_nag_263d9695.NagMessageLevel,
+        rule_original_name: builtins.str,
+        error_message: typing.Optional[builtins.str] = None,
+        finding_id: typing.Optional[builtins.str] = None,
+        suppression_reason: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''Represents the result of applying a CDK Nag rule to a resource.
+
+        :param compliance: Compliance status of the rule against the resource.
+        :param nag_pack_name: The name of the nag pack this rule is from.
+        :param resource: The resource the rule was applied to.
+        :param rule_explanation: Why the rule exists.
+        :param rule_id: The ID of the rule in this nag pack.
+        :param rule_info: Why the rule was triggered.
+        :param rule_level: The severity level of the rule.
+        :param rule_original_name: The original name of the rule (regardless of nag pack).
+        :param error_message: The error that was thrown, only set for error results.
+        :param finding_id: The finding that was checked, only set for non-compliant results.
+        :param suppression_reason: The reason the rule was suppressed, if any.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8449c5c2cfffdf3f73061d623bdbfb9a6f8c1a04846ab12f3c08d754a61977e5)
+            check_type(argname="argument compliance", value=compliance, expected_type=type_hints["compliance"])
+            check_type(argname="argument nag_pack_name", value=nag_pack_name, expected_type=type_hints["nag_pack_name"])
+            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
+            check_type(argname="argument rule_explanation", value=rule_explanation, expected_type=type_hints["rule_explanation"])
+            check_type(argname="argument rule_id", value=rule_id, expected_type=type_hints["rule_id"])
+            check_type(argname="argument rule_info", value=rule_info, expected_type=type_hints["rule_info"])
+            check_type(argname="argument rule_level", value=rule_level, expected_type=type_hints["rule_level"])
+            check_type(argname="argument rule_original_name", value=rule_original_name, expected_type=type_hints["rule_original_name"])
+            check_type(argname="argument error_message", value=error_message, expected_type=type_hints["error_message"])
+            check_type(argname="argument finding_id", value=finding_id, expected_type=type_hints["finding_id"])
+            check_type(argname="argument suppression_reason", value=suppression_reason, expected_type=type_hints["suppression_reason"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
+            "compliance": compliance,
+            "nag_pack_name": nag_pack_name,
+            "resource": resource,
+            "rule_explanation": rule_explanation,
+            "rule_id": rule_id,
+            "rule_info": rule_info,
+            "rule_level": rule_level,
+            "rule_original_name": rule_original_name,
+        }
+        if error_message is not None:
+            self._values["error_message"] = error_message
+        if finding_id is not None:
+            self._values["finding_id"] = finding_id
+        if suppression_reason is not None:
+            self._values["suppression_reason"] = suppression_reason
+
+    @builtins.property
+    def compliance(self) -> "NagResultCompliance":
+        '''Compliance status of the rule against the resource.'''
+        result = self._values.get("compliance")
+        assert result is not None, "Required property 'compliance' is missing"
+        return typing.cast("NagResultCompliance", result)
+
+    @builtins.property
+    def nag_pack_name(self) -> builtins.str:
+        '''The name of the nag pack this rule is from.'''
+        result = self._values.get("nag_pack_name")
+        assert result is not None, "Required property 'nag_pack_name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def resource(self) -> _aws_cdk_ceddda9d.CfnResource:
+        '''The resource the rule was applied to.'''
+        result = self._values.get("resource")
+        assert result is not None, "Required property 'resource' is missing"
+        return typing.cast(_aws_cdk_ceddda9d.CfnResource, result)
+
+    @builtins.property
+    def rule_explanation(self) -> builtins.str:
+        '''Why the rule exists.'''
+        result = self._values.get("rule_explanation")
+        assert result is not None, "Required property 'rule_explanation' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def rule_id(self) -> builtins.str:
+        '''The ID of the rule in this nag pack.'''
+        result = self._values.get("rule_id")
+        assert result is not None, "Required property 'rule_id' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def rule_info(self) -> builtins.str:
+        '''Why the rule was triggered.'''
+        result = self._values.get("rule_info")
+        assert result is not None, "Required property 'rule_info' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def rule_level(self) -> _cdk_nag_263d9695.NagMessageLevel:
+        '''The severity level of the rule.'''
+        result = self._values.get("rule_level")
+        assert result is not None, "Required property 'rule_level' is missing"
+        return typing.cast(_cdk_nag_263d9695.NagMessageLevel, result)
+
+    @builtins.property
+    def rule_original_name(self) -> builtins.str:
+        '''The original name of the rule (regardless of nag pack).'''
+        result = self._values.get("rule_original_name")
+        assert result is not None, "Required property 'rule_original_name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def error_message(self) -> typing.Optional[builtins.str]:
+        '''The error that was thrown, only set for error results.'''
+        result = self._values.get("error_message")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def finding_id(self) -> typing.Optional[builtins.str]:
+        '''The finding that was checked, only set for non-compliant results.'''
+        result = self._values.get("finding_id")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def suppression_reason(self) -> typing.Optional[builtins.str]:
+        '''The reason the rule was suppressed, if any.'''
+        result = self._values.get("suppression_reason")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "ExtendedNagResult(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="@aws/pdk.pdk_nag.Message",
     jsii_struct_bases=[],
@@ -173,6 +336,24 @@ class NagResult:
         )
 
 
+@jsii.enum(jsii_type="@aws/pdk.pdk_nag.NagResultCompliance")
+class NagResultCompliance(enum.Enum):
+    '''Possible statuses for nag rules.'''
+
+    COMPLIANT = "COMPLIANT"
+    '''Resource complies with the rule.'''
+    NON_COMPLIANT = "NON_COMPLIANT"
+    '''Resource does not comply with the rule.'''
+    NON_COMPLIANT_SUPPRESSED = "NON_COMPLIANT_SUPPRESSED"
+    '''Resource does not comply with the rule, but the rule was suppressed.'''
+    ERROR = "ERROR"
+    '''An error occurred applying the rule.'''
+    ERROR_SUPPRESSED = "ERROR_SUPPRESSED"
+    '''An error occurred applying the rule, but the rule was suppressed.'''
+    NOT_APPLICABLE = "NOT_APPLICABLE"
+    '''The rule is not applicable to the resource.'''
+
+
 class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws/pdk.pdk_nag.PDKNag"):
     '''Helper for create a Nag Enabled App.'''
 
@@ -360,6 +541,16 @@ class PDKNagApp(
 
         jsii.create(self.__class__, self, [props])
 
+    @jsii.member(jsii_name="addExtendedNagResults")
+    def add_extended_nag_results(self, *results: ExtendedNagResult) -> None:
+        '''
+        :param results: -
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__a2fcf25e53176b62e6528f199f19b5eb0ba7082819a349f5a61264769c40505e)
+            check_type(argname="argument results", value=results, expected_type=typing.Tuple[type_hints["results"], ...]) # pyright: ignore [reportGeneralTypeIssues]
+        return typing.cast(None, jsii.invoke(self, "addExtendedNagResults", [*results]))
+
     @jsii.member(jsii_name="addNagResult")
     def add_nag_result(
         self,
@@ -375,6 +566,14 @@ class PDKNagApp(
 
         return typing.cast(None, jsii.invoke(self, "addNagResult", [result]))
 
+    @jsii.member(jsii_name="extendedNagResults")
+    def extended_nag_results(self) -> typing.List[ExtendedNagResult]:
+        '''Returns a list of ExtendedNagResult.
+
+        Note: app.synth() must be called before this to retrieve results.
+        '''
+        return typing.cast(typing.List[ExtendedNagResult], jsii.invoke(self, "extendedNagResults", []))
+
     @jsii.member(jsii_name="nagResults")
     def nag_results(self) -> typing.List[NagResult]:
         '''Returns a list of NagResult.
@@ -682,8 +881,10 @@ class PDKNagAppProps(_aws_cdk_ceddda9d.AppProps):
 
 __all__ = [
     "AwsPrototypingChecks",
+    "ExtendedNagResult",
     "Message",
     "NagResult",
+    "NagResultCompliance",
     "PDKNag",
     "PDKNagApp",
     "PDKNagAppProps",
@@ -697,6 +898,23 @@ def _typecheckingstub__b8aa12b05f34ae8c5f2ba1473e38e19d866fb8f4b520412005d0fe346
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__8449c5c2cfffdf3f73061d623bdbfb9a6f8c1a04846ab12f3c08d754a61977e5(
+    *,
+    compliance: NagResultCompliance,
+    nag_pack_name: builtins.str,
+    resource: _aws_cdk_ceddda9d.CfnResource,
+    rule_explanation: builtins.str,
+    rule_id: builtins.str,
+    rule_info: builtins.str,
+    rule_level: _cdk_nag_263d9695.NagMessageLevel,
+    rule_original_name: builtins.str,
+    error_message: typing.Optional[builtins.str] = None,
+    finding_id: typing.Optional[builtins.str] = None,
+    suppression_reason: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__6c93182a4922d7452f57be229082f9c3d5dd9ca71941154fcdac4df76b43c528(
     *,
     message_description: builtins.str,
@@ -746,6 +964,12 @@ def _typecheckingstub__4f9f55608ad622f385b97d568c1b49a24059612e0fe4dde7d461d193d
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__a2fcf25e53176b62e6528f199f19b5eb0ba7082819a349f5a61264769c40505e(
+    *results: ExtendedNagResult,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__73ff6b436e20d432d5ee6d09f9604df61e816b58f9601272a85d1cfceb83d7bc(
     *,
     analytics_reporting: typing.Optional[builtins.bool] = None,
